akhdefo_functions.Filter_PreProcess — Akhdefo software documentation

# akhdefo_functions.Filter_PreProcess

akhdefo_functions.Filter_PreProcess(unfiltered_folderPath='', UDM2_maskfolderPath='', outpath_dir='', Udm_Mask_Option=False)

  This program prepare and uses filters to balanace raster image brightness

  ## Parameters

  unfiltered_folderPath : str

  UDM2_maskfolderPath : str

  outpath_dir : str

  Udm_Mask_Optionbool

    False if True the program uses planetlabs imagery unusable pixel mask to ignore and mask bad image pixels

  ## Returns

  geotif rasters

    Filtered geotif rasters

  Figures

    plotted filtered rasters and mask for bad pixels